pilas.habilidades.DispararConClick

Package pilas :: Module habilidades :: Class DispararConClick |
[hide private]
[frames] | no frames]

# Class DispararConClick

source code

    object --+
             |
     Habilidad --+
                 |
          Disparar --+
                     |
                    DispararConClick

Establece la habilidad de poder disparar un Actor o un objeto de tipo pilas.municion.Municion pulsando el boton izquierdo del ratón.

Instance Methods | [hide private]
__init__(self, *k, **kv) Construye la habilidad. | source code
cuando_hace_click(self, evento) | source code
cuando_termina_click(self, evento) | source code
pulsa_disparar(self) | source code
Inherited from `Disparar`: `actualizar`, `definir_colision`, `disparar`, `eliminar`, `get_frecuencia_de_disparo`, `get_municion`, `set_frecuencia_de_disparo`, `set_municion` Inherited from `Disparar` (private): `_agregar_disparo`, `_desplazar_proyectil`, `_eliminar_disparos_innecesarios` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `Disparar`: `frecuencia_de_disparo`, `municion` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *k, **kv) (Constructor) | source code
Construye la habilidad. :param municion: Municion o Actor que se disparará. :param grupo_enemigos: Actores que son considerados enemigos y con los que colisionará la munición disparada. :param cuando_elimina_enemigo: Método que será llamado cuando se produzca un impacto con un enemigo. :param frecuencia_de_disparo: El número de disparos por segundo que realizará. :param angulo_salida_disparo: Especifica el angulo por donde saldrá el disparo efectuado por el Actor. :param offset_disparo: Separación en pixeles (x,y) del disparo con respecto al centro del Actor. :param offset_origen_actor: Si el Actor no tiene su origen en el centro, con este parametro podremos colocar correctamente el disparo. :param cuando_dispara: Metodo que será llamado cuando se produzca un disparo. :param escala: Escala de los actores que serán disparados. :example:
    >>> mono = pilas.actores.Mono()
    >>> mono.aprender(pilas.habilidades.Disparar,
    >>>               municion=pilas.actores.proyectil.Bala,
    >>>               grupo_enemigos=enemigos,
    >>>               cuando_elimina_enemigo=eliminar_enemigo)
.. Overrides: object.__init__ (inherited documentation)

### pulsa_disparar(self) | source code
Overrides: Disparar.pulsa_disparar